@@ -20,6 +20,13 @@
 #'     \code{m}.  Vecchia approximation is only implemented for 
 #'     \code{cov = "matern"}.
 #'     
+#'     NOTE on OpenMP: The Vecchia implementation relies on OpenMP parallelization
+#'     for efficient computation.  This function will produce a warning message 
+#'     if the package was installed without OpenMP (this is the default for 
+#'     CRAN packages installed on Apple machines).  To set up OpenMP 
+#'     parallelization, download the package source code and install 
+#'     using the gcc/g++ compiler.  
+#'     
 #'     Proposals for \code{g} and \code{theta} follow a uniform sliding window 
 #'     scheme, e.g. 
 #'     
@@ -146,6 +153,7 @@ fit_one_layer <- function(x, y, nmcmc = 10000, verb = TRUE, g_0 = 0.01,
   
   tic <- proc.time()[3]
   cov <- match.arg(cov)
+  if (vecchia) check_omp()
   if (vecchia & cov == "exp2") {
     message("vecchia = TRUE requires Matern covariance, proceeding with cov = 'matern'")
     cov <- "matern" 
@@ -203,6 +211,13 @@ fit_one_layer <- function(x, y, nmcmc = 10000, verb = TRUE, g_0 = 0.01,
 #'     \code{m}.  Vecchia approximation is only implemented for 
 #'     \code{cov = "matern"}.
 #'     
+#'     NOTE on OpenMP: The Vecchia implementation relies on OpenMP parallelization
+#'     for efficient computation.  This function will produce a warning message 
+#'     if the package was installed without OpenMP (this is the default for 
+#'     CRAN packages installed on Apple machines).  To set up OpenMP 
+#'     parallelization, download the package source code and install 
+#'     using the gcc/g++ compiler.  
+#'     
 #'     Proposals for \code{g}, \code{theta_y}, and 
 #'     \code{theta_w} follow a uniform sliding window scheme, e.g.
 #'     
@@ -227,9 +242,7 @@ fit_one_layer <- function(x, y, nmcmc = 10000, verb = TRUE, g_0 = 0.01,
 #'     adjusted using the \code{settings} input.
 #'     
 #'     When \code{w_0 = NULL}, the hidden layer is initialized at \code{x} 
-#'     (i.e. the identity mapping).  The default prior mean of the hidden layer 
-#'     is zero, but may be adjusted to \code{x} using 
-#'     \code{settings = list(w_prior_mean = x)}.  If \code{w_0} is of dimension 
+#'     (i.e. the identity mapping).  If \code{w_0} is of dimension 
 #'     \code{nrow(x) - 1} by \code{D}, the final row is predicted using kriging. 
 #'     This is helpful in sequential design when adding a new input location 
 #'     and starting the MCMC at the place where the previous MCMC left off.
@@ -353,6 +366,7 @@ fit_two_layer <- function(x, y, D = ifelse(is.matrix(x), ncol(x), 1),
 
   tic <- proc.time()[3]
   cov <- match.arg(cov)
+  if (vecchia) check_omp()
   if (vecchia & cov == "exp2") {
     message("vecchia = TRUE requires matern covariance, proceeding with cov = 'matern'")
     cov <- "matern" 
@@ -414,6 +428,13 @@ fit_two_layer <- function(x, y, D = ifelse(is.matrix(x), ncol(x), 1),
 #'     approximation with specified conditioning set size \code{m}.  Vecchia 
 #'     approximation is only implemented for \code{cov = "matern"}.
 #'     
+#'     NOTE on OpenMP: The Vecchia implementation relies on OpenMP parallelization
+#'     for efficient computation.  This function will produce a warning message 
+#'     if the package was installed without OpenMP (this is the default for 
+#'     CRAN packages installed on Apple machines).  To set up OpenMP 
+#'     parallelization, download the package source code and install 
+#'     using the gcc/g++ compiler.  
+#'     
 #'     Proposals for \code{g}, 
 #'     \code{theta_y}, \code{theta_w}, and \code{theta_z} follow a uniform 
 #'     sliding window scheme, e.g.
@@ -442,8 +463,9 @@ fit_two_layer <- function(x, y, D = ifelse(is.matrix(x), ncol(x), 1),
 #'     
 #'     When \code{w_0 = NULL} and/or \code{z_0 = NULL}, the hidden layers are 
 #'     initialized at \code{x} (i.e. the identity mapping).  The default prior 
-#'     mean of the hidden layer is zero, but may be adjusted to \code{x} using 
-#'     \code{settings = list(w_prior_mean = x, z_prior_mean = x)}. 
+#'     mean of the inner hidden layer \code{z} is zero, but may be adjusted to \code{x} 
+#'     using \code{settings = list(z_prior_mean = x)}.  The prior mean of the
+#'     middle hidden layer \code{w} is set at zero is is not user adjustable.
 #'     If \code{w_0} and/or \code{z_0} is of dimension \code{nrow(x) - 1} by 
 #'     \code{D}, the final row is predicted using kriging. This is helpful in 
 #'     sequential design when adding a new input location and starting the MCMC 
@@ -537,7 +559,7 @@ fit_two_layer <- function(x, y, D = ifelse(is.matrix(x), ncol(x), 1),
 #' xx <- matrix(runif(n_test * d), ncol = d)
 #' yy <- apply(xx, 1, f)
 #' 
-#' i <- akima::interp(xx[, 1], xx[, 2], yy)
+#' i <- interp::interp(xx[, 1], xx[, 2], yy)
 #' image(i, col = heat.colors(128))
 #' contour(i, add = TRUE)
 #' points(x)
@@ -570,6 +592,7 @@ fit_three_layer <- function(x, y, D = ifelse(is.matrix(x), ncol(x), 1),
   
   tic <- proc.time()[3]
   cov <- match.arg(cov)
+  if (vecchia) check_omp()
   if (vecchia & cov == "exp2") {
     message("vecchia = TRUE requires matern covariance, proceeding with cov = 'matern'")
     cov <- "matern" 
